@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-Xorg
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2007-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Xorg::Read ;
-$Config::Model::Backend::Xorg::Read::VERSION = '1.109';
+
 use Any::Moose 'Role';
 
 use Carp ;
@@ -191,7 +191,7 @@ sub parse_mode_line {
     # force @v content to be numerical instead of strings
     my @v = map { 0 + $_ } splice @m,0,9 ;
 
-    my $load = "Mode:$mode DotClock=$v[0] ";
+    my $load = qq!Mode:"$mode" DotClock=$v[0] !;
     $load .= "HTimings disp=$v[1] syncstart=$v[2] syncend=$v[3] total=$v[4] - ";
     $load .= "VTimings disp=$v[5] syncstart=$v[6] syncend=$v[7] total=$v[8] - ";
 
@@ -205,8 +205,8 @@ sub parse_mode_line {
 sub parse_modes_list {
     my ($obj, $trash, $line_nb, @modes) = @_ ;
 
-    my $load = "Modes=".join(',',@modes);
-    $logger->debug( "parse_modes_list: ($line_nb))load '$load'");
+    my $load = 'Modes="'.join('","',@modes).'"';
+    $logger->debug( "parse_modes_list: ($line_nb)) load '$load'");
     $obj->load($load) ;
 }
 
@@ -218,7 +218,7 @@ sub parse_layout_screen {
     my $load;
 
     if ($obj->config_class_name eq 'Xorg::Device') {
-	$load = "Screen=$value";
+        $load = "Screen=$value";
     }
     else {
 	my ($num, $screen_id);
